@@ -11,13 +11,13 @@ pub struct Cli {
 
 #[derive(Subcommand)]
 pub enum CliCmd {
-  /// Compile a Kind2 file
-  Compile {
-    /// Input file
-    file: String,
-  },
-  /// Run and a Kind2 file (interpreted)
-  Run { 
+  // /// Compile a Kind2 file
+  //Compile {
+    ///// Input file
+    //file: String,
+  //},
+  /// Checks a Kind2 file
+  Check { 
     /// Input file
     file: String,
     #[clap(short, long)]
